@@ -59,7 +59,7 @@ test_that("db without icd10 codes loaded", {
   backends <- c("database", "data_frame")
   for (i in seq_along(backends)) {
     cdm <- mockVocabRef(backend = backends[i])
-    cdm$concept <- cdm$concept %>%
+    cdm$concept <- cdm$concept |>
     dplyr::filter(vocabulary_id != "ICD10")
   expect_message(codes <- getICD10StandardCodes(cdm = cdm))
   expect_true(length(codes) == 0)
