@@ -2,8 +2,8 @@ test_that("mock vocab db", {
   cdmDb <- mockVocabRef("database")
   cdmDF <- mockVocabRef("data_frame")
 
-  conceptFromDb <- cdmDb$concept %>% dplyr::collect()
-  conceptFromDf <- cdmDF$concept %>% dplyr::collect()
+  conceptFromDb <- cdmDb$concept |> dplyr::collect()
+  conceptFromDf <- cdmDF$concept |> dplyr::collect()
 
   expect_equal(conceptFromDb,
                     conceptFromDf,
