@@ -13,9 +13,9 @@ test_that("tests with mock db", {
                     cdm = cdm)
 
    # we should pick up knee osteoarthritis from our achilles tables
-   expect_true(all(stringr::str_detect(orphan_codes %>%
+   expect_true(all(stringr::str_detect(orphan_codes |>
      dplyr::pull("variable_level"), c("4", "5"))))
-   expect_equal(orphan_codes %>%
+   expect_equal(orphan_codes |>
                        dplyr::pull("estimate_value"),
                c("400", "200"))
    settings <- omopgenerics::settings(orphan_codes)
